@@ -147,6 +147,7 @@ class OrangeMoney(object):
         return response
 
     def checkTransactionStatus(self, data):
+        order_id = data["order_id"]
         auth_token = self.requestToken()
         LOGS.logger.info("\n\n====== OrangeMoney TransactionStatusRequest =======\n\n")
         LOGS.logger.info("\n\nauth_token: {}\n\n".format(auth_token))
@@ -197,9 +198,22 @@ class OrangeMoney(object):
                     "status": choices[status][-1],
                 }
                 LOGS.logger.info("\n\nFinal result\n\n")
-                LOGS.logger.info(response)
+                LOGS.logger.info(
+                    "[OrangeMoney][] {}\n".format(
+                        order_id,
+                        response,
+                    )
+                )
+                REDIS_DB.hmset(
+                    "request:payment:{}".format(data["pay_token"]),
+                    {
+                        "partner_ref": jresponse['txnid'],
+                    },
+                )
             return response
 
+# status requests functions
+
     def checkTransactionStatusRedis(self, order_id):
         """Used by 4D in order to check a given transaction current status"""
 
